AurisBadgeVariant enum

The semantic intent of an AurisBadge, mapped to a scheme role color.

Inheritance
Available extensions

Values

amber → const AurisBadgeVariant

Dim amber — the resting / informational default.

gold → const AurisBadgeVariant

Active gold — emphasized.

slate → const AurisBadgeVariant

Cool slate secondary.

danger → const AurisBadgeVariant

Danger / error.

success → const AurisBadgeVariant

Success / confirmation.

inactive → const AurisBadgeVariant

Inactive / disabled-looking (dim text, no accent).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AurisBadgeVariant>
A constant List of the values in this enum, in order of their declaration.