AurisStepState enum
The state of an AurisStepIndicator marker.
Values
- inactive → const AurisStepState
-
Not yet reached — dim border, dim number.
- active → const AurisStepState
-
The current step — gold border + glow, gold number.
- complete → const AurisStepState
-
Finished — solid gold fill with a check glyph.
- error → const AurisStepState
-
Errored — danger border + fill with a warning glyph.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AurisStepState> - A constant List of the values in this enum, in order of their declaration.