onChanged property
Called with the requested new value when the user toggles the control. Null disables the switch.
Implementation
final ValueChanged<bool>? onChanged;
Called with the requested new value when the user toggles the control. Null disables the switch.
final ValueChanged<bool>? onChanged;