AurisProgressVariant enum
The semantic intent of an AurisProgressBar, mapped to a scheme role color and its depth-by-intent glow.
Values
- primary → const AurisProgressVariant
-
Active gold — the default.
- secondary → const AurisProgressVariant
-
Cool slate secondary.
- danger → const AurisProgressVariant
-
Danger / over-threshold.
- success → const AurisProgressVariant
-
Success / complete.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AurisProgressVariant> - A constant List of the values in this enum, in order of their declaration.