AurisTerminalLine class
- Annotations
Constructors
- AurisTerminalLine(String text, {AurisTerminalLineType type = AurisTerminalLineType.normal})
-
Creates a terminal line of
type(default AurisTerminalLineType.normal).const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
The line text (rendered monospace, as-is).
final
- type → AurisTerminalLineType
-
The semantic type that colors the line.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited